# Lecture 04 - Other Markdown extensions

There are many other extensions in particular in the [Material Documentation][1], 
here are some that are activated in Mkdocs-et.

[1]: https://squidfunk.github.io/mkdocs-material/reference/abbreviations/


## Content tabs

Content tabs are widely used in this document. 

=== "C"

    ``` c
    #include <stdio.h>

    int main(void) {
      printf("Hello world!\n");
      return 0;
    }
    ```

=== "C++"

    ``` c++
    #include <iostream>

    int main(void) {
      std::cout << "Hello world!" << std::endl;
      return 0;
    }
    ```

This example was obtained by

```
=== "C"

    ``` c
    #include <stdio.h>

    int main(void) {
      printf("Hello world!\n");
      return 0;
    }
    ```

=== "C++"

    ``` c++
    #include <iostream>

    int main(void) {
      std::cout << "Hello world!" << std::endl;
      return 0;
    }
    ```
```


## Admonition

Admonitions, also known as *call-outs*, are an excellent choice for including
side content without significantly interrupting the document flow. Material for
MkDocs provides several [different types][1] of admonitions and allows for
the inclusion and nesting of arbitrary content.

[1]: https://squidfunk.github.io/mkdocs-material/reference/admonitions/#usage

For instance,

!!! example "Printing numbers"

    This example shows how to print numbers in Python3:

    ``` py
    for i in range(10):
        print(i)
    ```

is obtained by

``` md
!!! example "Printing numbers"

    This example shows how to print numbers in Python3:

    ``` py
    for i in range(10):
        print(i)
    ```
```

The title can be removed using an empty string `""`:

!!! note ""

    This call-out is without a title and was obtained with

    ``` md
    !!! note ""

        This call-out is without a title ...
    ```


Different types of admonition are possible, see [here][2].

[2]: https://squidfunk.github.io/mkdocs-material/reference/admonitions/#supported-types

!!! success "Different types"

    They provide different icons and colors.



## Collapsible blocs

Collapsible blocks are a special kind of admonition :


??? note "Block closed by default"

    The text is inside a collapsible block.

???+ note "Block open by default:"

    The text is inside a collapsible block.

These examples are obtained by putting `???` or `???+` at the beginning:

``` md
??? note "Block closed by default"

    The text is inside a collapsible block.

???+ note "Block open by default:"

    The text is inside a collapsible block.
```


## Floating paragraph

!!! info inline end "Sidebar"

    This text is in a floating paragraph, which will appear to the right of the
    normal text, or full width on mobile screens.

Floating paragraphs are also admonitions; they are inserted in the Markdown
document *before* the normal text.

To obtain such a floating box, add before the title `inline end` to place the
box to the right, or `inline` for left.

If there's insufficient space to render the admonition next to the block, the
admonition will stretch to the full width of the viewport, e.g. on mobile
viewports.

``` md
!!! info inline end "Sidebar"

    This text is in a floating paragraph, which will appear to the right of the
    normal text, or full width on mobile screens.
```


## Image alignment


![A Tux](../images/tux2.gif){ align=left }

It is also possible to align the text next to an image.

If there's insufficient space to render the text next to the image, the image
will stretch to the full width of the viewport, e.g. on mobile viewports.

This example was obtained with

``` md
![A Tux](../images/tux2.gif){ align=left }
```

As the Material's documentation [states][imcap], it is not possible to add a
caption to an image in pure Markdown. For that, you need to revert to HTML.

[imcap]: https://squidfunk.github.io/mkdocs-material/reference/images/#image-captions

For instance,

<figure>
  <img src="https://pageperso.lis-lab.fr/~edouard.thiel/ez-draw/images/bubblets.png"
       width="320" alt="Bubblets" />
  <figcaption>This is a caption</figcaption>
</figure>

can be obtained by

``` html
<figure>
  <img src="https://pageperso.lis-lab.fr/~edouard.thiel/ez-draw/images/bubblets.png"
       width="320" alt="Bubblets" />
  <figcaption>This is a caption</figcaption>
</figure>
```

## Include a file

To include a file, write `--8<-- "filename"` on a line by itself. The natural
place for these files is the directory `skel-mkdocs-et/includes`.

Here is the result of `:::md --8<-- "includes/example1.md"` :

--8<-- "includes/example1.md"

and there is the result of `:::md --8<-- "includes/example2.txt"` :

--8<-- "includes/example2.txt"


