---
food: pizza
fruits :
  - apples
  - pears
  - cherries
---

# Practical Work 04 - Jinja2

[Jinja2][1] is a modern and designer-friendly templating language for Python, 
modelled after Django’s templates.

[1]: https://jinja.palletsprojects.com/en/2.11.x/templates/


## Comments

It is important to understand that the Jinja processor parses the source prior
to the Markdown processor.

{% raw %}
Jinja comments made with `{# ... #}` will therefore be removed *before* the 
Markdown parsing, and so whether these comments are in normal text or in a 
block of code.
{% endraw %}

If you need to insert `{{ "{#" }}` in the text or in the code, you must protect
it between `:::jinja {{ "{% raw %}" }}` and `:::jinja {{ "{% endraw %}" }}`. 
Another method is to write {% raw %}`:::jinja {{ "{#" }}`{% endraw %}.

Here is an example with some bash code :

=== "Rendered Output"

    The table length if obtained by `:::bash ${{ "{#" }}table[@]}`.

    {% raw %}
    The string length of the element `i` is `:::bash ${#table[i]}`.

    ``` bash
    if test ${#foo} -ge 5; then
        echo "ok"
    fi
    ```
    {% endraw %}

=== "Markdown"
        {% raw %}
        The table length if obtained by `:::bash ${{ "{#" }}table[@]}`.
        {% endraw %}
        {{ "{% raw %}" }}{% raw %}
        The string length of the element `i` is `:::bash ${#table[i]}`.

        ``` bash
        if test ${#foo} -ge 5; then
            echo "ok"
        fi
        ```
        {% endraw %}{{ "{% endraw %}" }}


## Meta variables

Meta variables can be defined at the very top of a document in a YAML header,
delimited by `---` lines.

For instance in this page, the beginning is

``` yaml
---
food: pizza
fruits :
  - apples
  - pears
  - cherries
---
```

It defines the variable `food` as a string and the variable `fruits` as a list;
they are stored in the dict `{% raw %}{{ page.meta }}{% endraw %}`:

=== "Markdown"
    {% raw %}
    ``` jinja
    Il like eating a {{ page.meta.food }}.

    The fruits are: {% for f in fruits %} {{ f }}{% endfor %}.
    ```
    {% endraw %}

=== "Rendered Output"

    Il like eating a {{ page.meta.food }}.

    The fruits are: {% for f in fruits %} {{ f }}{% endfor %}.


## Global variables

The scope of a meta variable is limited to its document.

To define a variable that is visible in all documents, you can set it in a
separate file and import it:

=== "Markdown"
    {% raw %}
    In `includes/mydefs.html`:

    ``` jinja
    {% set short_url %}http://j.mp/mkdocs-et{% endset %}
    ```

    In this document:

    ``` jinja
    {% import "includes/mydefs.html" as my %}

    The short link to this site is <{{ my.short_url }}>.
    ```
    {% endraw %}

=== "Rendered Output"

    {% import "includes/mydefs.html" as my %}

    The short link to this site is <{{ my.short_url }}>.


## Global table of content

The markdown tag `[TOC]` output the page TOC:

[TOC]

A global TOC can be obtained using Jinja:

{% raw %}
``` jinja
{% for page in navigation.pages %}
- [{{ page.title }}](../{{ page.url }}){% endfor %}
```
{% endraw %}

will render as

{% for page in navigation.pages %}
- [{{ page.title }}](../{{ page.url }}){% endfor %}


## Macro informations

Here is the output of ```:::jinja {% raw %}{{ macros_info() }}{% endraw %}```:

---

{{ macros_info() }}


